@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/lineedits.h   3.1.2   edited Nov 8 10:35 $
+** $Id: qt/lineedits.h   3.2.3   edited May 22 12:37 $
 **
 ** Copyright (C) 1992-2000 Trolltech AS.  All rights reserved.
 **
@@ -24,13 +24,14 @@ public:
     LineEdits( QWidget *parent = 0, const char *name = 0 );
 
 protected:
-    QLineEdit *lined1, *lined2, *lined3, *lined4;
-    QComboBox *combo1, *combo2, *combo3, *combo4;
+    QLineEdit *lined1, *lined2, *lined3, *lined4, *lined5;
+    QComboBox *combo1, *combo2, *combo3, *combo4, *combo5;
 
 protected slots:
     void slotEchoChanged( int );
     void slotValidatorChanged( int );
     void slotAlignmentChanged( int );
+    void slotInputMaskChanged( int );
     void slotReadOnlyChanged( int );
 };
 
